@@ -34,6 +34,7 @@
  *		your option) any later version.
  */
 
+#include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <fcntl.h>
@@ -56,9 +57,10 @@
 #endif
 #include "net-locale.h"
 #include "hostname.h"
+#include "version.h"
 
 char *Release = RELEASE,
-     *Version = "hostname 2.08";
+     *Version = VERSION;
      
 static char *program_name;
 static int  opt_v;
@@ -66,7 +68,7 @@ static int  opt_v;
 static void sethname(char *);
 static void setdname(char *);
 static void showhname(char *, int);
-static void usage(void);
+static void usage(FILE *);
 static void version(void);
 static void setfilename(char *,int);
 
@@ -88,7 +90,6 @@ static void sethname(char *hname)
 				fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_toolong,
 							   "%s: name too long\n"), program_name);
 				break;
-			default:
 		}
 		NLS_CATCLOSE(catfd)
 		exit(1);
@@ -110,7 +111,6 @@ static void setdname(char *dname)
 				fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_dname_toolong,
 							   "%s: name too long\n"), program_name);
 				break;
-			default:
 		}
 		NLS_CATCLOSE(catfd)
 		exit(1);
@@ -177,7 +177,6 @@ static void showhname(char *hname, int c)
 			if (p != NULL) *p = '\0';
 			printf("%s\n", hp->h_name);
 			break;
-		default:
 	}
 }
 
@@ -228,50 +227,50 @@ static void setfilename(char * name,int what)
 static void version(void)
 {
 #ifndef STANDALONE
-	fprintf(stderr,"%s\n",Release);
+	fprintf(stdout,"%s\n",Release);
 #endif
-	fprintf(stderr,"%s\n",Version);
+	fprintf(stdout,"%s\n",Version);
 	NLS_CATCLOSE(catfd)
-	exit(-1);
+	exit(0);
 }
 
-static void usage(void)
+static void usage(FILE *stream)
 {
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage1, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage1, 
 		"Usage: hostname [-v] {hostname|-F file}      set host name (from file)\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage2, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage2, 
 		"       domainname [-v] {nisdomain|-F file}   set NIS domain name (from file)\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage3, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage3, 
 		"       hostname [-v] [-d|-f|-s|-a|-i|-y]     display formated name\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage4, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage4, 
 		"       hostname [-v]                         display host name\n\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage5, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage5, 
 		"       hostname -V|--version|-h|--help       print info and exit\n\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage6, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage6, 
 		"    dnsdomainname=hostname -d, {yp,nis,}domainname=hostname -y\n\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage7, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage7, 
 		"    -s, --short           short host name\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage8, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage8, 
 		"    -a, --alias           alias names\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage9, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage9, 
 		"    -i, --ip-address      addresses for the host name\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage10, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage10, 
 		"    -f, --fqdn, --long    long host name (FQDN)\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage11, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage11, 
 		"    -d, --domain          DNS domain name\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage12, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage12, 
 		"    -y, --yp, --nis       NIS/YP domain name\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage13, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage13, 
 		"    -F, --file            read host name or NIS domain name from given file\n\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage14, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage14, 
 		"   This command can get or set the host name or the NIS domain name. You can\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage15, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage15, 
 		"   also get the DNS domain or the FQDN (fully qualified domain name).\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage16, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage16, 
 		"   Unless you are using bind or NIS for host lookups you can change the\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage17, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage17, 
 		"   FQDN (Fully Qualified Domain Name) and the DNS domain name (which is\n"));
-	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage18, 
+	fprintf(stream,NLS_CATGETS(catfd, hostnameSet, hostname_usage18, 
 		"   part of the FQDN) in the /etc/hosts file.\n"));
 	NLS_CATCLOSE(catfd)
 	exit(-1);
@@ -348,8 +347,10 @@ int main(int argc, char **argv)
 			version();
 		case '?':
 		case 'h':
+			usage(stdout);
+			break;
 		default:
-			usage();
+			usage(stderr);
 
 	};
 
